@@ -7,6 +7,10 @@
 #include <iostream>
 #include <string>
 
+SIGC_USING_STD(cout)
+SIGC_USING_STD(endl)
+SIGC_USING_STD(string)
+
 class foo
 {
   public:
@@ -40,4 +44,7 @@ int main()
   sl1 = sl2;
   sl1(str);
   std::cout << str << std::endl;
+
+  // test copy ctor
+  sigc::slot<void,int> s1_clone(s1);
 }
